/* Copyright  2014 Annpoint, s.r.o.
   Use of this software is subject to license terms. 
   http://www.daypilot.org/

   If you have purchased a DayPilot Pro license, you are allowed to use this 
   code under the conditions of DayPilot Pro License Agreement:

   http://www.daypilot.org/files/LicenseAgreement.pdf

   Otherwise, you are allowed to use it for evaluation purposes only under 
   the conditions of DayPilot Pro Trial License Agreement:
   
   http://www.daypilot.org/files/LicenseAgreementTrial.pdf
   
*/

using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Web.UI.WebControls;
using DayPilot.Utils;
using DayPilot.Web.Ui;
using DayPilot.Web.Ui.Data;
using DayPilot.Web.Ui.Enums;
using DayPilot.Web.Ui.Events;
using DayPilot.Web.Ui.Events.Scheduler;
using CommandEventArgs = DayPilot.Web.Ui.Events.CommandEventArgs;
using CornerShape = DayPilot.Web.Ui.Enums.Scheduler.CornerShape;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            Scheduler.StartDate = new DateTime(DateTime.Today.Year, DateTime.Today.Month, 1);
            Scheduler.Days = 365;
            LoadResources();
            //SetDataSourceAndBind(Scheduler.StartDate, Scheduler.EndDate);
        }

    }

    private void SetDataSourceAndBind(DateTime start, DateTime end)
    {
        Scheduler.DataSource = GetData(start, end);
        Scheduler.DataStartField = "eventstart";
        Scheduler.DataEndField = "eventend";
        Scheduler.DataIdField = "id";
        Scheduler.DataTextField = "name";
        Scheduler.DataResourceField = "resource_id";
        Scheduler.DataBind();

    }

    private DataTable GetData(DateTime start, DateTime end)
    {
        SqlDataAdapter da = new SqlDataAdapter("SELECT * FROM [event] WHERE NOT (([eventend] <= @start) OR ([eventstart] >= @end))", ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString);
        da.SelectCommand.Parameters.AddWithValue("start", start);
        da.SelectCommand.Parameters.AddWithValue("end", end);

        DataTable dt = new DataTable();
        da.Fill(dt);

        return dt;
    }
    
    private DataTable GetResources()
    {
        SqlDataAdapter da = new SqlDataAdapter("SELECT * FROM [resource] ORDER BY [name]", ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString);

        DataTable dt = new DataTable();
        da.Fill(dt);

        return dt;
    }

    private void LoadResources()
    {
        Scheduler.Resources.Clear();

        DataTable resources = GetResources();
        foreach (DataRow row in resources.Rows)
        {
            Scheduler.Resources.Add((string) row["name"], Convert.ToString(row["id"]));
        }
    }

    protected void Scheduler_Command(object sender, CommandEventArgs e)
    {
        switch (e.Command)
        {
            case "refresh":
                SetDataSourceAndBind(Scheduler.ViewPort.Start, Scheduler.ViewPort.End);
                Scheduler.Update();
                break;
        }
    }

    protected void Scheduler_BeforeEventRender(object sender, BeforeEventRenderEventArgs e)
    {
        e.EventMoveVerticalEnabled = false;
        if (!String.IsNullOrEmpty(e.DataItem["color"] as string))
        {
            e.DurationBarColor = (string) e.DataItem["color"];
            e.DurationBarBackColor = "#333";
        }
    }

    protected void Scheduler_BeforeResHeaderRender(object sender, BeforeResHeaderRenderEventArgs e)
    {
    }

    protected void Scheduler_EventMove(object sender, EventMoveEventArgs e)
    {
        DbUpdateEvent(e.Value, e.NewStart, e.NewEnd, e.Text);
    }

    private void DbUpdateEvent(string id, DateTime start, DateTime end, string name)
    {
        using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString))
        {
            con.Open();
            SqlCommand cmd = new SqlCommand("UPDATE [event] SET eventstart = @start, eventend = @end, name = @name WHERE id = @id", con);
            cmd.Parameters.AddWithValue("id", id);
            cmd.Parameters.AddWithValue("start", start);
            cmd.Parameters.AddWithValue("end", end);
            cmd.Parameters.AddWithValue("name", name);
            cmd.ExecuteNonQuery();
        }
    }

    protected void Scheduler_EventResize(object sender, EventResizeEventArgs e)
    {
        DbUpdateEvent(e.Value, e.NewStart, e.NewEnd, e.Text);
    }

    protected void LinkButtonSample_Click(object sender, EventArgs e)
    {
        string[] colors = { "#1066A8", "#DE0000", "#00B100", "#FF9508" };

        DbClearResources();
        DbClearEvents();

        for (int i = 1; i <= 25; i++)
        {
            DbInsertResource("Resource " + i.ToString("D2"), i);

            DateTime start = new DateTime(DateTime.Today.Year, DateTime.Today.Month, 1); //.AddHours(12);
            Random random = new Random();
            for (int x = 1; x <= 1000; x++)
            {
                int duration = random.Next(1, 5);
                string color = colors[random.Next(0, 4)];
                DateTime end = start.AddDays(duration);
                DbInsertEvent(start, end, "Task " + i + "/" + x, i, color);
                start = end.AddDays(random.Next(0, 2));
            }

        }

        Response.Redirect(Request.Url.PathAndQuery);
    }

    private void DbInsertResource(string name, int id)
    {
        using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString))
        {
            con.Open();
            SqlCommand cmd = new SqlCommand("INSERT INTO [resource] (name, id) VALUES(@name, @id)", con);
            cmd.Parameters.AddWithValue("name", name);
            cmd.Parameters.AddWithValue("id", id);
            cmd.ExecuteNonQuery();
        }
    }

    private void DbInsertEvent(DateTime start, DateTime end, string name, int resource, string color)
    {
        using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString))
        {
            con.Open();
            SqlCommand cmd = new SqlCommand("INSERT INTO [event] (eventstart, eventend, name, resource_id, color) VALUES(@start, @end, @name, @resource, @color)", con);
            cmd.Parameters.AddWithValue("start", start);
            cmd.Parameters.AddWithValue("end", end);
            cmd.Parameters.AddWithValue("name", name);
            cmd.Parameters.AddWithValue("resource", resource);
            cmd.Parameters.AddWithValue("color", color);
            cmd.ExecuteNonQuery();
        }
    }

    private void DbClearEvents()
    {
        using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString))
        {
            con.Open();
            SqlCommand cmd = new SqlCommand("delete from [event]", con);
            cmd.ExecuteNonQuery();
        }
    }

    private void DbClearResources()
    {
        using (SqlConnection con = new SqlConnection(ConfigurationManager.ConnectionStrings["daypilot"].ConnectionString))
        {
            con.Open();
            SqlCommand cmd = new SqlCommand("delete from [resource]", con);
            cmd.ExecuteNonQuery();
        }
    }

    protected void Scheduler_OnScroll(object sender, ScrollEventArgs e)
    {
        SetDataSourceAndBind(Scheduler.ViewPort.Start, Scheduler.ViewPort.End);
        Scheduler.Update();
    }
}
