﻿' Copyright � 2014 Annpoint, s.r.o.
'   Use of this software is subject to license terms. 
'   http://www.daypilot.org/
'
'   If you have purchased a DayPilot Pro license, you are allowed to use this 
'   code under the conditions of DayPilot Pro License Agreement:
'
'   http://www.daypilot.org/files/LicenseAgreement.pdf
'
'   Otherwise, you are allowed to use it for evaluation purposes only under 
'   the conditions of DayPilot Pro Trial License Agreement:
'   
'   http://www.daypilot.org/files/LicenseAgreementTrial.pdf
'   
'

Imports System
Imports System.Configuration
Imports System.Data
Imports System.Data.SqlClient
Imports System.Drawing
Imports System.Drawing.Imaging
Imports System.IO
Imports System.Web.UI.WebControls
Imports DayPilot.Utils
Imports DayPilot.Web.Ui
Imports DayPilot.Web.Ui.Data
Imports DayPilot.Web.Ui.Enums
Imports DayPilot.Web.Ui.Events
Imports DayPilot.Web.Ui.Events.Scheduler
Imports CommandEventArgs = DayPilot.Web.Ui.Events.CommandEventArgs
Imports CornerShape = DayPilot.Web.Ui.Enums.Scheduler.CornerShape

Partial Public Class _Default
	Inherits System.Web.UI.Page

	Protected Sub Page_Load(ByVal sender As Object, ByVal e As EventArgs)
		If Not IsPostBack Then
			Scheduler.StartDate = New Date(Date.Today.Year, Date.Today.Month, 1)
			Scheduler.Days = 365
			LoadResources()
			'SetDataSourceAndBind(Scheduler.StartDate, Scheduler.EndDate);
		End If

	End Sub

	Private Sub SetDataSourceAndBind(ByVal start As Date, ByVal [end] As Date)
		Scheduler.DataSource = GetData(start, [end])
		Scheduler.DataStartField = "eventstart"
		Scheduler.DataEndField = "eventend"
		Scheduler.DataIdField = "id"
		Scheduler.DataTextField = "name"
		Scheduler.DataResourceField = "resource_id"
		Scheduler.DataBind()

	End Sub

	Private Function GetData(ByVal start As Date, ByVal [end] As Date) As DataTable
		Dim da As New SqlDataAdapter("SELECT * FROM [event] WHERE NOT (([eventend] <= @start) OR ([eventstart] >= @end))", ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)
		da.SelectCommand.Parameters.AddWithValue("start", start)
		da.SelectCommand.Parameters.AddWithValue("end", [end])

		Dim dt As New DataTable()
		da.Fill(dt)

		Return dt
	End Function

	Private Function GetResources() As DataTable
		Dim da As New SqlDataAdapter("SELECT * FROM [resource] ORDER BY [name]", ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)

		Dim dt As New DataTable()
		da.Fill(dt)

		Return dt
	End Function

	Private Sub LoadResources()
		Scheduler.Resources.Clear()

		Dim resources As DataTable = GetResources()
		For Each row As DataRow In resources.Rows
			Scheduler.Resources.Add(DirectCast(row("name"), String), Convert.ToString(row("id")))
		Next row
	End Sub

	Protected Sub Scheduler_Command(ByVal sender As Object, ByVal e As CommandEventArgs)
		Select Case e.Command
			Case "refresh"
                SetDataSourceAndBind(Scheduler.ViewPort.Start, Scheduler.ViewPort.End)
				Scheduler.Update()
		End Select
	End Sub

	Protected Sub Scheduler_BeforeEventRender(ByVal sender As Object, ByVal e As BeforeEventRenderEventArgs)
		e.EventMoveVerticalEnabled = False
		If Not String.IsNullOrEmpty(TryCast(e.DataItem("color"), String)) Then
			e.DurationBarColor = CStr(e.DataItem("color"))
			e.DurationBarBackColor = "#333"
		End If
	End Sub

	Protected Sub Scheduler_BeforeResHeaderRender(ByVal sender As Object, ByVal e As BeforeResHeaderRenderEventArgs)
	End Sub

	Protected Sub Scheduler_EventMove(ByVal sender As Object, ByVal e As EventMoveEventArgs)
		DbUpdateEvent(e.Value, e.NewStart, e.NewEnd, e.Text)
	End Sub



	Private Sub DbUpdateEvent(ByVal id As String, ByVal start As Date, ByVal [end] As Date, ByVal name As String)
		Using con As New SqlConnection(ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)
			con.Open()
			Dim cmd As New SqlCommand("UPDATE [event] SET eventstart = @start, eventend = @end, name = @name WHERE id = @id", con)
			cmd.Parameters.AddWithValue("id", id)
			cmd.Parameters.AddWithValue("start", start)
			cmd.Parameters.AddWithValue("end", [end])
			cmd.Parameters.AddWithValue("name", name)
			cmd.ExecuteNonQuery()
		End Using
	End Sub

	Protected Sub Scheduler_EventResize(ByVal sender As Object, ByVal e As EventResizeEventArgs)
		DbUpdateEvent(e.Value, e.NewStart, e.NewEnd, e.Text)
    End Sub
	Protected Sub LinkButtonSample_Click(ByVal sender As Object, ByVal e As EventArgs)
		Dim colors() As String = { "#1066A8", "#DE0000", "#00B100", "#FF9508" }

		DbClearResources()
		DbClearEvents()

		For i As Integer = 1 To 25
			DbInsertResource("Resource " & i.ToString("D2"), i)

			Dim start As New Date(Date.Today.Year, Date.Today.Month, 1) '.AddHours(12);
			Dim random As New Random()
			For x As Integer = 1 To 1000
				Dim duration As Integer = random.Next(1, 5)
				Dim color As String = colors(random.Next(0, 4))
				Dim [end] As Date = start.AddDays(duration)
				DbInsertEvent(start, [end], "Task " & i & "/" & x, i, color)
				start = [end].AddDays(random.Next(0, 2))
			Next x

		Next i

		Response.Redirect(Request.Url.PathAndQuery)
	End Sub

	Private Sub DbInsertResource(ByVal name As String, ByVal id As Integer)
		Using con As New SqlConnection(ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)
			con.Open()
			Dim cmd As New SqlCommand("INSERT INTO [resource] (name, id) VALUES(@name, @id)", con)
			cmd.Parameters.AddWithValue("name", name)
			cmd.Parameters.AddWithValue("id", id)
			cmd.ExecuteNonQuery()
		End Using
	End Sub

	Private Sub DbInsertEvent(ByVal start As Date, ByVal [end] As Date, ByVal name As String, ByVal resource As Integer, ByVal color As String)
		Using con As New SqlConnection(ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)
			con.Open()
			Dim cmd As New SqlCommand("INSERT INTO [event] (eventstart, eventend, name, resource_id, color) VALUES(@start, @end, @name, @resource, @color)", con)
			cmd.Parameters.AddWithValue("start", start)
			cmd.Parameters.AddWithValue("end", [end])
			cmd.Parameters.AddWithValue("name", name)
			cmd.Parameters.AddWithValue("resource", resource)
			cmd.Parameters.AddWithValue("color", color)
			cmd.ExecuteNonQuery()
		End Using
	End Sub

	Private Sub DbClearEvents()
		Using con As New SqlConnection(ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)
			con.Open()
			Dim cmd As New SqlCommand("delete from [event]", con)
			cmd.ExecuteNonQuery()
		End Using
	End Sub

	Private Sub DbClearResources()
		Using con As New SqlConnection(ConfigurationManager.ConnectionStrings("daypilot").ConnectionString)
			con.Open()
			Dim cmd As New SqlCommand("delete from [resource]", con)
			cmd.ExecuteNonQuery()
		End Using
	End Sub

	Protected Sub Scheduler_OnScroll(ByVal sender As Object, ByVal e As ScrollEventArgs)
		SetDataSourceAndBind(Scheduler.ViewPort.Start, Scheduler.ViewPort.End)
		Scheduler.Update()
	End Sub
End Class
